@@ -102,6 +102,18 @@ def in_cwd():
 
     return configs
 
+def expandpath(_path):
+    """Return expanded path based on user's ``$HOME`` and ``env``.
+
+    :py:func:`os.path.expanduser` and :py:func:`os.path.expandvars`
+
+    :param _path: path to expand
+    :type _path: string
+    :returns: expanded path
+    :rtype: string
+
+    """
+    return os.path.expandvars(os.path.expanduser(_path))
 
 def inline(sconf):
     """ Return config in inline form, opposite of :meth:`config.expand`.
@@ -139,7 +151,7 @@ def inline(sconf):
     return sconf
 
 
-def expand(sconf, cwd=None):
+def expand(sconf, cwd=None, parent=None):
     """Return config with shorthand and inline properties expanded.
 
     This is necessary to keep the code in the :class:`WorkspaceBuilder` clean
@@ -172,11 +184,21 @@ def expand(sconf, cwd=None):
     # Any config section, session, window, pane that can contain the
     # 'shell_command' value
     if 'start_directory' in sconf:
+        sconf['start_directory'] = expandpath(sconf['start_directory'])
         start_path = sconf['start_directory']
         if any(start_path.startswith(a) for a in ['.', './']):
+            # if window has a session, or pane has a window with a
+            # start_directory of . or ./, make sure the start_directory can be
+            # relative to the parent.
+            #
+            # This is for the case where you may be loading a config from
+            # outside your shell current directory.
+            if parent:
+                cwd = parent['start_directory']
             start_path = os.path.normpath(os.path.join(cwd, start_path))
             sconf['start_directory'] = start_path
 
+
     if 'before_script' in sconf:
         before_script = sconf['before_script']
         if any(before_script.startswith(a) for a in ['.', './']):
@@ -198,7 +220,7 @@ def expand(sconf, cwd=None):
     # recurse into window and pane config items
     if 'windows' in sconf:
         sconf['windows'] = [
-            expand(window) for window in sconf['windows']
+            expand(window, parent=sconf) for window in sconf['windows']
         ]
     elif 'panes' in sconf:
 
@@ -235,7 +257,7 @@ def expand(sconf, cwd=None):
                 p['shell_command'] = []
 
             pconf.update(p)
-        sconf['panes'] = [expand(pane) for pane in sconf['panes']]
+        sconf['panes'] = [expand(pane, parent=sconf) for pane in sconf['panes']]
 
     return sconf
 
